==> haskell-openpgp-asciiarmor-0.1.2-126-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-openpgp-asciiarmor.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 openpgp-asciiarmor
version:              0.1.2
visibility:           public
id:                   openpgp-asciiarmor-0.1.2-4ZUz9kMg1Wo4Ied1YKUNHK
key:                  openpgp-asciiarmor-0.1.2-4ZUz9kMg1Wo4Ied1YKUNHK
license:              MIT
copyright:            2012-2019 Clint Adams
maintainer:           Clint Adams <clint@debian.org>
author:               Clint Adams
homepage:             http://floss.scru.org/openpgp-asciiarmor
synopsis:             OpenPGP (RFC4880) ASCII Armor codec
description:          OpenPGP (RFC4880) ASCII Armor codec
category:             Codec, Data
abi:                  3efc9f8ceb62bc5be972cc40c441a3e0
exposed:              True
exposed-modules:
    Codec.Encryption.OpenPGP.ASCIIArmor
    Codec.Encryption.OpenPGP.ASCIIArmor.Decode
    Codec.Encryption.OpenPGP.ASCIIArmor.Encode
    Codec.Encryption.OpenPGP.ASCIIArmor.Types

hidden-modules:
    Data.Digest.CRC24 Codec.Encryption.OpenPGP.ASCIIArmor.Multipart
    Codec.Encryption.OpenPGP.ASCIIArmor.Utils

import-dirs:          /usr/lib/ghc-8.10.5/site-local/openpgp-asciiarmor-0.1.2
library-dirs:         /usr/lib/ghc-8.10.5/site-local/openpgp-asciiarmor-0.1.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.5/openpgp-asciiarmor-0.1.2
hs-libraries:         HSopenpgp-asciiarmor-0.1.2-4ZUz9kMg1Wo4Ied1YKUNHK
depends:
    attoparsec-0.14.1-qO4BENHL0SHN8QdgrNcG6 base-4.14.2.0
    base64-bytestring-1.2.0.1-6PvrigrzgN5CFxMJsxx0QP binary-0.8.8.0
    bytestring-0.10.12.0

haddock-interfaces:
    /usr/share/doc/haskell-openpgp-asciiarmor/html/openpgp-asciiarmor.haddock

haddock-html:         /usr/share/doc/haskell-openpgp-asciiarmor/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-openpgp-asciiarmor-0.1.2-127-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-openpgp-asciiarmor.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 openpgp-asciiarmor
version:              0.1.2
visibility:           public
id:                   openpgp-asciiarmor-0.1.2-88rsPiCODUVBh1etVMa00p
key:                  openpgp-asciiarmor-0.1.2-88rsPiCODUVBh1etVMa00p
license:              MIT
copyright:            2012-2019 Clint Adams
maintainer:           Clint Adams <clint@debian.org>
author:               Clint Adams
homepage:             http://floss.scru.org/openpgp-asciiarmor
synopsis:             OpenPGP (RFC4880) ASCII Armor codec
description:          OpenPGP (RFC4880) ASCII Armor codec
category:             Codec, Data
abi:                  3aa634e24b970f549937a2e33e8fbf48
exposed:              True
exposed-modules:
    Codec.Encryption.OpenPGP.ASCIIArmor
    Codec.Encryption.OpenPGP.ASCIIArmor.Decode
    Codec.Encryption.OpenPGP.ASCIIArmor.Encode
    Codec.Encryption.OpenPGP.ASCIIArmor.Types

hidden-modules:
    Data.Digest.CRC24 Codec.Encryption.OpenPGP.ASCIIArmor.Multipart
    Codec.Encryption.OpenPGP.ASCIIArmor.Utils

import-dirs:          /usr/lib/ghc-9.0.1/site-local/openpgp-asciiarmor-0.1.2
library-dirs:         /usr/lib/ghc-9.0.1/site-local/openpgp-asciiarmor-0.1.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.1/openpgp-asciiarmor-0.1.2
hs-libraries:         HSopenpgp-asciiarmor-0.1.2-88rsPiCODUVBh1etVMa00p
depends:
    attoparsec-0.14.1-ANDnhONsuNz9itknOOpUk5 base-4.15.0.0
    base64-bytestring-1.2.0.1-ApIXqNH7Qw19tHOhhZxfrm binary-0.8.8.0
    bytestring-0.10.12.1

haddock-interfaces:
    /usr/share/doc/haskell-openpgp-asciiarmor/html/openpgp-asciiarmor.haddock

haddock-html:         /usr/share/doc/haskell-openpgp-asciiarmor/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
